<?php
/**
 * lino Theme Customizer
 *
 * @package lino
 * @since lino 1.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function lino_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
}
add_action( 'customize_register', 'lino_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function lino_customize_preview_js() {
	wp_enqueue_script( 'lino_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'lino_customize_preview_js' );

/**
 * Customizer CSS
 */
function lino_enqueue_customizer_controls_styles() {

  wp_register_style( 'lino-customizer-controls', get_template_directory_uri() . '/inc/customizer-controls.css', NULL, NULL, 'all' );
  wp_enqueue_style( 'lino-customizer-controls' );

  }
add_action( 'customize_controls_print_styles', 'lino_enqueue_customizer_controls_styles' );

/**
 * Customizer Admin JS
 */

function lino_enqueue_customizer_admin_scripts() {

  wp_register_script( 'customizer-admin-js', get_template_directory_uri() . '/js/customizer-admin.js', array( 'jquery' ), NULL, true );
  wp_enqueue_script( 'customizer-admin-js' );

  }

add_action( 'customize_controls_print_footer_scripts', 'lino_enqueue_customizer_admin_scripts' );

/**
 * Customizer
 *
 * @since lino 1.0
 */
function lino_theme_customizer( $wp_customize ) {
	/*--------------------------------------------------------------
		Logo
	--------------------------------------------------------------*/
	/* logo section */
	$wp_customize->add_section( 'pk_logo_section' , array(
		'title' => __( 'Logo', 'lino' ),
	    'capability' => 'edit_theme_options',
	    'priority'    => 10,
	    'description' => 'Upload a logo',
	) );
	
	// upload a logo
	$wp_customize->add_setting( 'pk_logo', array(
        'sanitize_callback' => 'esc_url_raw',
    ) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pk_logo', array(
	    'label'    => __( 'Logo', 'lino' ),
	    'priority' => 10,
	    'section'  => 'pk_logo_section',
	    'settings' => 'pk_logo',
	) ) );

	/*--------------------------------------------------------------
		Portfolio Options
	--------------------------------------------------------------*/	
    $wp_customize->add_section( 'lino_theme_options', array(
        'title'             => __( 'Portfolio Options', 'lino' ),
        'priority'          => 20,
    ) );
	
	/* Hide Title on Portfolio Page Template */
	$wp_customize->add_setting( 'lino_hide_portfolio_page_content', array(
            'default'           => '',
			'sanitize_callback' => 'lino_sanitize_checkbox',
    ) );
	
    $wp_customize->add_control( 'lino_hide_portfolio_page_content', array(
            'label'             => __( 'Hide title and content on Portfolio Page Template', 'lino' ),
            'section'           => 'lino_theme_options',
            'type'              => 'checkbox',
    ) );
	
	/* Hide Featured Image on Single Portfolio */
	$wp_customize->add_setting( 'lino_hide_featured_image', array(
            'default'           => '',
			'sanitize_callback' => 'lino_sanitize_checkbox',
    ) );
	
    $wp_customize->add_control( 'lino_hide_featured_image', array(
            'label'             => __( 'Hide Featured Image on Single Portfolio', 'lino' ),
            'section'           => 'lino_theme_options',
            'type'              => 'checkbox',
    ) );

	/*--------------------------------------------------------------
		Colors
	--------------------------------------------------------------*/
	/* Header Background Color */
    $wp_customize->add_setting( 'lino_header_bg_color', array(
        'default' => '#ffffff',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control ( $wp_customize, 'lino_header_bg_color', array(
		'label' => __( 'Header Background Color', 'lino' ),
		'priority' => 1,
		'section' => 'colors',
		'settings' => 'lino_header_bg_color',
	) ) );

	/* Header Title Color */
    $wp_customize->add_setting( 'lino_header_title_color', array(
        'default' => '#000000',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_header_title_color', array(
		'label' => __( 'Header Title Color', 'lino' ),
		'priority' => 2,
		'section' => 'colors',
		'settings' => 'lino_header_title_color',
	) ) );

	/* Header Tagline Color */
    $wp_customize->add_setting( 'lino_header_tagline_color', array(
        'default' => '#B1B2B3',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_header_tagline_color', array(
		'label' => __( 'Header Tagline Color', 'lino' ),
		'priority' => 3,
		'section' => 'colors',
		'settings' => 'lino_header_tagline_color',
	) ) );

	/* Body Font Color */
    $wp_customize->add_setting( 'lino_body_color', array(
        'default' => '#888',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_body_color', array(
		'label' => __( 'Body Font Color', 'lino' ),
		'priority' => 4,
		'section' => 'colors',
		'settings' => 'lino_body_color',
	) ) );

	/* Link Color */
    $wp_customize->add_setting( 'lino_link_color', array(
        'default' => '#000',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_link_color', array(
		'label' => __( 'Link Color', 'lino' ),
		'priority' => 5,
		'section' => 'colors',
		'settings' => 'lino_link_color',
	) ) );

	/* Link Hover Color */
    $wp_customize->add_setting( 'lino_hover_color', array(
        'default' => '#999',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_hover_color', array(
		'label' => __( 'Link Hover Color', 'lino' ),
		'priority' => 6,
		'section' => 'colors',
		'settings' => 'lino_hover_color',
	) ) );

	/* Post Title Link Color */
    $wp_customize->add_setting( 'lino_post_color', array(
        'default' => '#000',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_post_color', array(
		'label' => __( 'Post Title Color', 'lino' ),
		'priority' => 7,
		'section' => 'colors',
		'settings' => 'lino_post_color',
	) ) );

	/* Post Title Link Hover Color */
    $wp_customize->add_setting( 'lino_post_hover_color', array(
        'default' => '#999',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_post_hover_color', array(
		'label' => __( 'Post Title Hover Color', 'lino' ),
		'priority' => 8,
		'section' => 'colors',
		'settings' => 'lino_post_hover_color',
	) ) );

	/* Widget Title Link Color */
    $wp_customize->add_setting( 'lino_widget_title_color', array(
        'default' => '#999',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_widget_title_color', array(
		'label' => __( 'Widget Title Color', 'lino' ),
		'priority' => 9,
		'section' => 'colors',
		'settings' => 'lino_widget_title_color',
	) ) );

	/* Icons Color */
    $wp_customize->add_setting( 'lino_icons_color', array(
        'default' => '#999',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_icons_color', array(
		'label' => __( 'Icons Color', 'lino' ),
		'priority' => 10,
		'section' => 'colors',
		'settings' => 'lino_icons_color',
	) ) );

	/* Blockquote Color */
    $wp_customize->add_setting( 'lino_blockquote_color', array(
        'default' => '#f2f2f2',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_blockquote_color', array(
		'label' => __( 'Blockquote Color', 'lino' ),
		'priority' => 11,
		'section' => 'colors',
		'settings' => 'lino_blockquote_color',
	) ) );

	/* Button Color */
    $wp_customize->add_setting( 'lino_button_color', array(
        'default' => '#fff',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_button_color', array(
		'label' => __( 'Button Color', 'lino' ),
		'priority' => 12,
		'section' => 'colors',
		'settings' => 'lino_button_color',
	) ) );

	/* Button Text Color */
    $wp_customize->add_setting( 'lino_button_text_color', array(
        'default' => '#888',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lino_button_text_color', array(
		'label' => __( 'Button Text Color', 'lino' ),
		'priority' => 13,
		'section' => 'colors',
		'settings' => 'lino_button_text_color',
	) ) );

	class lino_Customize_Alpha_Color_Control extends WP_Customize_Control {

	    public $type = 'alphacolor';
	    //public $palette = '#3FADD7,#555555,#666666, #F5f5f5,#333333,#404040,#2B4267';
	    public $palette = true;
	    public $default = '#666666';

	    protected function render() {
	        $id = 'customize-control-' . str_replace( '[', '-', str_replace( ']', '', $this->id ) );
	        $class = 'customize-control customize-control-' . $this->type; ?>
	        <li id="<?php echo esc_attr( $id ); ?>" class="<?php echo esc_attr( $class ); ?>">
	            <?php $this->render_content(); ?>
	        </li>
	    <?php }

	    public function render_content() { ?>
	        <label>
	            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	            <input type="text" data-palette="<?php echo $this->palette; ?>" data-default-color="<?php echo $this->default; ?>" value="<?php echo intval( $this->value() ); ?>" class="lino-color-control" <?php $this->link(); ?>  />
	        </label>
	    <?php }
	}

	/* Grid Posts Hover Color */
    $wp_customize->add_setting( 'lino_grid_posts_color', array(
        'default' => '#ffffff',
    ) );

	$wp_customize->add_control( new lino_Customize_Alpha_Color_Control( $wp_customize, 'lino_grid_posts_color', array(
		'label' => __( 'Grid Posts Hover Color', 'lino' ),
		'palette' => true,
		'priority' => 14,
		'section' => 'colors',
		'settings' => 'lino_grid_posts_color',
	) ) );

	/*--------------------------------------------------------------
		Footer Credits
	--------------------------------------------------------------*/
	$wp_customize->add_section( 'lino_footer_section' , array(
	    'title'       => __( 'Footer Credits', 'lino' ),
	    'priority'    => 80,
	    'description' => 'Custom Footer Credits',
	) );

	$wp_customize->add_setting('lino_footer');

	$wp_customize->add_control(
	    'lino_footer',
	    array(
	        'label' => 'Footer Credits',
	        'section' => 'lino_footer_section',
	        'type' => 'text',
	    )
	);

	/*--------------------------------------------------------------
		Custom CSS
	--------------------------------------------------------------*/
	class lino_Customize_Textarea_Control extends WP_Customize_Control {
	    public $type = 'textarea';
	 
	    public function render_content() {
	        ?>
	            <label>
	                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	                <textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
	            </label>
	        <?php
	    }
	}

	$wp_customize->add_section( 'lino_css_section' , array(
	    'title'       => __( 'Custom CSS', 'lino' ),
	    'priority'    => 90,
	    'description' => 'You can add your custom CSS',
	) );

	$wp_customize->add_setting( 'lino_css' );
	 
	$wp_customize->add_control(
	    new lino_Customize_Textarea_Control(
	        $wp_customize,
	        'lino_css',
	        array(
	            'label' => 'Custom CSS',
	            'section' => 'lino_css_section',
	            'settings' => 'lino_css'
	        )
	    )
	);

	/*--------------------------------------------------------------
		Footer Scripts
	--------------------------------------------------------------*/
	$wp_customize->add_section( 'lino_scripts_section' , array(
	    'title'       => __( 'Custom Footer Scripts', 'lino' ),
	    'priority'    => 100,
	    'description' => 'You can add your custom Scripts in the footer without the tag "script". For example: google analytics.',
	) );

	$wp_customize->add_setting( 'lino_scripts' );
	 
	$wp_customize->add_control(
	    new lino_Customize_Textarea_Control(
	        $wp_customize,
	        'lino_scripts',
	        array(
	            'label' => 'Custom Scripts',
	            'section' => 'lino_scripts_section',
	            'settings' => 'lino_scripts'
	        )
	    )
	);
}
add_action('customize_register', 'lino_theme_customizer');

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean true if portfolio page template displays title and content.
*/
function lino_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
			return true;
	} else {
			return false;
	}
}

/**
 * Customizer Apply Style
 *
 * @since lino 1.0
 */
if ( ! function_exists( 'lino_apply_style' ) ) :
  	
  	function lino_apply_style() {	
		if ( get_theme_mod('lino_header_bg_color') || 
			 get_theme_mod('lino_header_title_color') || 
			 get_theme_mod('lino_header_tagline_color') || 
			 get_theme_mod('lino_body_color') || 
			 get_theme_mod('lino_link_color') || 
			 get_theme_mod('lino_hover_color') || 
			 get_theme_mod('lino_post_color') || 
			 get_theme_mod('lino_post_hover_color') || 
			 get_theme_mod('lino_widget_title_color') || 
			 get_theme_mod('lino_icons_color') || 
			 get_theme_mod('lino_blockquote_color') || 
			 get_theme_mod('lino_button_color') || 
			 get_theme_mod('lino_button_text_color') ||  
			 get_theme_mod('lino_grid_posts_color') || 
			 get_theme_mod('lino_css')
		) { 
		?>
			<style id="lino-style-settings">				
				<?php if ( get_theme_mod('lino_header_bg_color') ) : ?>
					.site-header {
						background-color: <?php echo get_theme_mod('lino_header_bg_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('lino_header_title_color') ) : ?>
					.site-title a {
						color: <?php echo get_theme_mod('lino_header_title_color');  ?> !important;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('lino_header_tagline_color') ) : ?>
					.site-description {
						color: <?php echo get_theme_mod('lino_header_tagline_color');  ?>;
					}
				<?php endif; ?>
				
				<?php if ( get_theme_mod('lino_body_color') ) : ?>
					body,
					button,
					input,
					select,
					textarea {
						color: <?php echo get_theme_mod('lino_body_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('lino_link_color') ) : ?>
					a,
					a:visited {
						color: <?php echo get_theme_mod('lino_link_color');  ?>;
					}
				<?php endif; ?>
			
				<?php if ( get_theme_mod('lino_hover_color') ) : ?>
					a:hover,
					a:focus,
					a:active {
						color: <?php echo get_theme_mod('lino_hover_color');  ?>;
					}
				<?php endif; ?>
				
				<?php if ( get_theme_mod('lino_post_color') ) : ?>
					.entry-title,
					.entry-title a {
						color: <?php echo get_theme_mod('lino_post_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('lino_post_hover_color') ) : ?>
					.entry-title a:hover {
						color: <?php echo get_theme_mod('lino_post_hover_color');  ?>;
					}
				<?php endif; ?>
				
				<?php if ( get_theme_mod('lino_widget_title_color') ) : ?>
					.widget-title {
						color: <?php echo get_theme_mod('lino_widget_title_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('lino_icons_color') ) : ?>
					.social:before  {
						color: <?php echo get_theme_mod('lino_icons_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('lino_blockquote_color') ) : ?>
					blockquote {
						border-left: 5px solid <?php echo get_theme_mod('lino_blockquote_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('lino_button_color') || get_theme_mod('lino_button_text_color') ) : ?>
					button, 
					input[type="button"], 
					input[type="reset"], 
					input[type="submit"] {
						border: 1px solid <?php echo get_theme_mod('lino_button_color');  ?>;
						background: <?php echo get_theme_mod('lino_button_color');  ?>;
						color: <?php echo get_theme_mod('lino_button_text_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('lino_grid_posts_color') ) : ?>
					.grid-wrap a,
					.page-template-page-filter .type-jetpack-portfolio .post-wrap {
						background-color: <?php echo get_theme_mod('lino_grid_posts_color');  ?>;
					}
				<?php endif; ?>
			</style>
			<style id="lino-custom-css">
				<?php if ( get_theme_mod('lino_css') ) : ?>
					<?php echo get_theme_mod('lino_css');  ?>;
				<?php endif; ?>
			</style>
		<?php
    }
}
endif;
add_action( 'wp_head', 'lino_apply_style' );

/**
 * Customizer Footer
 *
 * @since lino 1.0
 */
if ( ! function_exists( 'lino_apply_footer' ) ) :
  	
  	function lino_apply_footer() {	
		if ( get_theme_mod('lino_scripts') ) { 
		?>

		<script id="lino-custom-scriptss">
			<?php if ( get_theme_mod('lino_scripts') ) : ?>
				<?php echo get_theme_mod('lino_scripts');  ?>;
			<?php endif; ?>
		</script>
		<?php
    }
}
endif;
add_action('wp_footer', 'lino_apply_footer');